app

package
v0.5.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 20, 2026 License: MIT Imports: 14 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Model

type Model struct {
	// contains filtered or unexported fields
}

Model is the root application model for the TUI

func NewModel

func NewModel(client *azdevops.MultiClient, cfg *config.Config, currentVersion string, commitHash string) Model

NewModel creates a new application model with the given Azure DevOps client, config, version, and commit hash.

func (Model) Init

func (m Model) Init() tea.Cmd

Init initializes the application

func (Model) Update

func (m Model) Update(msg tea.Msg) (tea.Model, tea.Cmd)

Update handles incoming messages and updates the model

func (Model) View

func (m Model) View() string

View renders the application UI

type Tab

type Tab int

Tab represents the active tab in the application

const (
	TabPullRequests Tab = iota // Pull Requests tab (key '1')
	TabWorkItems               // Work Items tab (key '2')
	TabPipelines               // Pipelines tab (key '3')
)

type ThemeNotFoundError

type ThemeNotFoundError struct {
	ThemeName  string
	ThemesPath string
}

ThemeNotFoundError represents an error when a requested theme is not found.

func (*ThemeNotFoundError) Error

func (e *ThemeNotFoundError) Error() string

Jump to