Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Model ¶
type Model struct {
// contains filtered or unexported fields
}
Model is the root application model for the TUI
func NewModel ¶
func NewModel(client *azdevops.MultiClient, cfg *config.Config, currentVersion string, commitHash string) Model
NewModel creates a new application model with the given Azure DevOps client, config, version, and commit hash.
type ThemeNotFoundError ¶
ThemeNotFoundError represents an error when a requested theme is not found.
func (*ThemeNotFoundError) Error ¶
func (e *ThemeNotFoundError) Error() string
Click to show internal directories.
Click to hide internal directories.